/* Input Sensor Box
 * ----------------
 *
 * Uses Arduino as a sensor box external to the computer
 * it allows to read both the digital ports, and the analog 
 * ones. By default it makes a polling of all the inputs and 
 * retrieves them to the serial port. It will be sent in the 
 * format:
 *
 * {A|D} {number} {H|L|0..8}
 *
 * A --> Analog sensor
 * D --> Digital sensor
 * number --> 00, 01, 02 .. 12; indicates the pin number
 * H --> High
 * L --> Low
 * 0..8 --> We encode any analog sensor in values between 0 and 8
 *          (this can be changed until 1024 values per sensor)
 *
 * http://www.0j0.org
 * copyleft 2005 DojoDave for DojoCorp
 */
 
int ledPin = 13;
int digRead = 0;
int anaRead = 0;

void setup() 
{
  pinMode(ledPin, OUTPUT);      // sets the digital pin as output
  beginSerial(9600);
}


int treatValue(int data)
{
  return (data * 9 / 256) + 48;
}

void serialEOLN(char type, int num1, int num2, int data) {
  serialWrite(type);
  serialWrite(num1);
  serialWrite(num2);
  serialWrite(data);
  serialWrite(10);
  serialWrite(13);
}

void blinkLED(void) {
  digitalWrite(ledPin, HIGH);
  delay(250);
  digitalWrite(ledPin, LOW);
}

void loop() 
{
//  serialEvent2();
  for (int count = 2; count <= 9; count++) {
    digRead = digitalRead(count);
    if (digRead == HIGH) {
      serialEOLN('D', '0', 48 + count, 'H');
    } else {
      serialEOLN('D', '0', 48 + count, 'L');
    }
  }
  for (int count = 0; count <= 2; count++) {
    digRead = digitalRead(count + 10);
    if (digRead == HIGH) {
      serialEOLN('D', '1', 48 + count, 'H');
    } else {
      serialEOLN('D', '1', 48 + count, 'L');
    }
  }
  for (int count = 0; count <= 5; count++) {
    anaRead = analogRead(count);
    delay(100);
    serialEOLN('A', '0', 48 + count, treatValue(anaRead));
    delay(100);
  }
  blinkLED();
}